# API Reference

This page provides an auto-generated summary of xpersist’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.

```{eval-rst}
.. currentmodule:: xpersist
```

## CacheStore

```{eval-rst}
.. autosummary::
    xpersist.cache.CacheStore
    xpersist.cache.Artifact

.. autoclass:: xpersist.cache.CacheStore
    :members:

.. autopydantic_model:: xpersist.cache.Artifact
```

## Serializers

```{eval-rst}
.. autosummary::
    xpersist.serializers.Serializer
    xpersist.serializers.pick_serializer

.. autopydantic_model:: xpersist.serializers.Serializer
.. autofunction:: xpersist.serializers.pick_serializer
```

## Prefect Caching

```{eval-rst}
.. autosummary::
    xpersist.prefect.result.XpersistResult

.. autoclass:: xpersist.prefect.result.XpersistResult
    :members:
```

## Registry

```{eval-rst}
.. autosummary::
    xpersist.registry.registry

.. autoclass:: xpersist.registry.registry
    :members:
```
